import express, { Router, Request, Response } from 'express'
import { ProductService, productService } from '../services/products'
import { ProductServicePg, productServicePg } from '../services/productsPg'
export class ProductsController {
    private router: Router
    private service: ProductService | ProductServicePg

    constructor() {
        this.router = express.Router()
        this.router.get('/', this.getProducts)
        this.router.get('/:id', this.getProductById)
        this.router.post('/', this.addProduct)
        switch(process.env.DB) {
            case 'file':
                this.service = productService
                break
            case 'postgres':
                this.service = productServicePg
                break
            default:
                this.service = productServicePg
        }
    }

    public getRouter = (): Router => {
        return this.router
    }

    private getProducts = async (req: Request, res: Response): Promise<void> => {
        const response = await this.service.getProducts()
        res.send(response)
    }

    private getProductById = async (req: Request, res: Response): Promise<void> => {
        const response = await this.service.getProductById(req.params.id)
        res.send(response)
    }

    private addProduct = async (req: Request, res: Response): Promise<void> => {
        const response = await this.service.addProduct(req.body)
        res.send(response)
    }
}