import express, { Express } from 'express'
import { HealthCheckController } from './controllers/healthCheck'
import { ProductsController } from './controllers/products'
import { db } from './repository/fileDB'
import cors from 'cors'
import dotenv from 'dotenv'
import { postgresDB } from './repository/postgresDB'
dotenv.config()


class App {
    private app: Express
    constructor() {
        this.app = express()
        this.app.use(express.json())
        this.app.use(cors())
    }

    public init = async (): Promise<void> => {
        try {
            this.app.use('/health-check', new HealthCheckController().getRouter())
            this.app.use('/products', new ProductsController().getRouter())
            this.app.listen(process.env.APP_PORT, () => {
                console.log(`Server is running on port ${process.env.APP_PORT}`)
            })
            
            switch(process.env.DB) {
                case 'file':
                    db.init()
                    break
                case 'postgres':
                    await postgresDB.init()
                    break
                default:
                    await postgresDB.init()
            }
        } catch(err) {
            console.log(err)
        }
    }

}


const app = new App()
app.init()